@@ -55,7 +55,8 @@ def get_items(client: list[TonlibClient] or TonlibClient, addresses: list, filen
             tasks.append(get_item(client[d % len(client)], addr, nft_items, items))
             # print(d % len(client))
             d += 1
-        asyncio.run(asyncio.gather(*tasks))
+        # asyncio.set_event_loop(asyncio.SelectorEventLoop())
+        asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks))
         print('DONE')
     if len(nft_items) < len(addresses):
         raise Exception('SCANNED NOT ALL ITEMS')
